@@ -3,10 +3,7 @@
 # modify it under the same terms as Perl itself.
 
 package Convert::ASN1;
-{
-  $Convert::ASN1::VERSION = '0.25';
-}
-
+$Convert::ASN1::VERSION = '0.29';
 use strict;
 use warnings;
 
@@ -92,7 +89,7 @@ sub _enc_integer {
     my $os = i2osp($_[3], ref($_[3]) || $_[0]->{encode_bigint} || 'Math::BigInt');
     my $len = length $os;
     my $msb = (vec($os, 0, 8) & 0x80) ? 0 : 255;
-    $len++, $os = chr($msb) . $os if $msb xor $_[3] > 0;
+    $len++, $os = pack("C",$msb) . $os if $msb xor $_[3] > 0;
     $_[4] .= asn_encode_length($len);
     $_[4] .= $os;
   }
@@ -124,15 +121,15 @@ sub _enc_bitstring {
     my $less = (8 - ($_[3]->[1] & 7)) & 7;
     my $len = ($_[3]->[1] + 7) >> 3;
     $_[4] .= asn_encode_length(1+$len);
-    $_[4] .= chr($less);
+    $_[4] .= pack("C",$less);
     $_[4] .= substr($$vref, 0, $len);
     if ($less && $len) {
-      substr($_[4],-1) &= chr((0xff << $less) & 0xff);
+      substr($_[4],-1) &= pack("C",(0xff << $less) & 0xff);
     }
   }
   else {
     $_[4] .= asn_encode_length(1+length $$vref);
-    $_[4] .= chr(0);
+    $_[4] .= pack("C",0);
     $_[4] .= $$vref;
   }
 }
@@ -158,7 +155,7 @@ sub _enc_null {
 # 0      1    2       3     4     5      6
 # $optn, $op, $stash, $var, $buf, $loop, $path
 
-  $_[4] .= chr(0);
+  $_[4] .= pack("C",0);
 }
 
 
@@ -190,19 +187,19 @@ sub _enc_real {
 
   # Zero
   unless ($_[3]) {
-    $_[4] .= chr(0);
+    $_[4] .= pack("C",0);
     return;
   }
 
   require POSIX;
 
-  # +oo (well we use HUGE_VAL as Infinity is not avaliable to perl)
+  # +oo (well we use HUGE_VAL as Infinity is not available to perl)
   if ($_[3] >= POSIX::HUGE_VAL()) {
     $_[4] .= pack("C*",0x01,0x40);
     return;
   }
 
-  # -oo (well we use HUGE_VAL as Infinity is not avaliable to perl)
+  # -oo (well we use HUGE_VAL as Infinity is not available to perl)
   if ($_[3] <= - POSIX::HUGE_VAL()) {
     $_[4] .= pack("C*",0x01,0x41);
     return;
@@ -211,7 +208,7 @@ sub _enc_real {
   if (exists $_[0]->{'encode_real'} && $_[0]->{'encode_real'} ne 'binary') {
     my $tmp = sprintf("%g",$_[3]);
     $_[4] .= asn_encode_length(1+length $tmp);
-    $_[4] .= chr(1); # NR1?
+    $_[4] .= pack("C",1); # NR1?
     $_[4] .= $tmp;
     return;
   }
@@ -228,13 +225,13 @@ sub _enc_real {
 
   while($mantissa > 0.0) {
     ($mantissa, my $int) = POSIX::modf($mantissa * (1<<8));
-    $eMant .= chr($int);
+    $eMant .= pack("C",$int);
   }
   $exponent -= 8 * length $eMant;
 
   _enc_integer(undef, undef, undef, $exponent, $eExp);
 
-  # $eExp will br prefixed by a length byte
+  # $eExp will be prefixed by a length byte
   
   if (5 > length $eExp) {
     $eExp =~ s/\A.//s;
@@ -245,7 +242,7 @@ sub _enc_real {
   }
 
   $_[4] .= asn_encode_length(1 + length($eMant) + length($eExp));
-  $_[4] .= chr($first);
+  $_[4] .= pack("C",$first);
   $_[4] .= $eExp;
   $_[4] .= $eMant;
 }
